#include "GkrLeg.h"
#include <HkxGroupPosControl.h>

void setup() {
  delay(2000); // time to open the serial monitor

  // Create the Communication instance
  HkxPrint printoutLib(Serial, 9600, true, true, false);
  HkxPrint printoutCode(printoutLib, true, true, true);
  HkxCommunication communication(HKX_666666, Serial1, printoutLib);
  // Create the group of servo poscontrol
  HkxPosControl servo0(0, communication, printoutCode);
  HkxPosControl servo1(1, communication, printoutCode);
  HkxPosControl servo2(2, communication, printoutCode);
  
  HkxPosControl* arrayServos[3] = {&servo0, &servo1, &servo2};
  HkxGroupPosControl groupServos(3, arrayServos, printoutCode);
  int16_t shoulderPosition[3] = {0,398,1624};
  int16_t legDistances[3] = {305, 435, 1450};
  GkrLeg maJambe(groupServos, printoutCode, shoulderPosition, legDistances);

  // Setup zeros
  printoutCode.infoPrint(F("*** Calibration ***"));
  int16_t zeroPos[] = {-13, -26, -26};
  for(int i=0; i<3; i++){
    groupServos.getServo(i).setZeroPosition(zeroPos[i]);
    groupServos.getServo(i).setLoad(HKX_NO_VALUE, HKX_NO_VALUE, HKX_NO_VALUE, HKX_NO_VALUE, HKX_NO_VALUE, 1023);
  }
  groupServos.getServo(2).reverseRotation();
  printoutCode.infoPrint(F("--> Calibration performed "));
  printPosition(printoutCode, maJambe);
  delay(2000);

  int16_t noForce[3] = {0,0,0};
  int16_t force[3] = {0,0,-10};
  printoutCode.infoPrint(F("*** Move Space 1 ***"));
  HkxMaybe<hkxLEDControl> tabLedMove[] = {HKX_LED_WHITE, HKX_LED_WHITE, HKX_LED_WHITE};
  int16_t spacePosition[3] = {500, 1200, 200};
  maJambe.moveSpace(spacePosition, 2000, tabLedMove,noForce);
  printPosition(printoutCode, maJambe);

  printoutCode.infoPrint(F("*** Move Space 2 ***"));
  int16_t spacePosition2[3] = {500, 1200, -15};
  maJambe.moveSpace(spacePosition2, 2000, tabLedMove,noForce);
  printPosition(printoutCode, maJambe);
  delay(1000);
  printoutCode.infoPrint(F("*** Move Space 3 ***"));
  int16_t spacePosition3[3] = {-500, 1200, -15};
  maJambe.moveSpace(spacePosition3, 10000, tabLedMove,force);
  printPosition(printoutCode, maJambe);
  delay(1000);
  printoutCode.infoPrint(F("*** Move Space 4 ***"));
  int16_t spacePosition4[3] = {-500, 1200, 200};
  maJambe.moveSpace(spacePosition4, 2000, tabLedMove,force);
  printPosition(printoutCode, maJambe);
  delay(1000);

}

void loop() {
  // put your main code here, to run repeatedly:

}

void printPosition(HkxPrint& printout,GkrLeg& myLeg){
  int16_t spacePosition[3];
  myLeg.getCurrentSpacePosition(spacePosition, true);
  String message = "Space Position: X = ";
  message += (float)spacePosition[0]/10;
  message += "\t Y = ";
  message += (float)spacePosition[1]/10;
  message += "\t Z = ";
  message += (float)spacePosition[2]/10;
  printout.infoPrint(message);

  int16_t jointPosition[3];
  myLeg.getCurrentJointPosition(jointPosition, true);
  message = "Joint Position: th0 = ";
  message += (float)jointPosition[0]/10;
  message += "\t th1 = ";
  message += (float)jointPosition[1]/10;
  message += "\t th2 = ";
  message += (float)jointPosition[2]/10;
  printout.infoPrint(message);
}

